{ pkgs, ... }:

{
  # Bootloader.
  boot.loader.grub.enable = true;
  boot.loader.grub.device = "/dev/sda";
  boot.loader.grub.useOSProber = false;

  # Setup keyfile
  boot.initrd.secrets = {
    "/crypto_keyfile.bin" = null;
  };

  # Enable grub cryptodisk
  boot.loader.grub.enableCryptodisk = true;

  boot.initrd.luks.devices."luks-efc0285c-812e-4946-936b-37e737fb72eb".keyFile = "/crypto_keyfile.bin";

  networking.hostName = "lift";

  networking.networkmanager.enable = true;
  systemd.network.wait-online.enable = false;
  boot.initrd.systemd.network.wait-online.enable = false;


  # bluetooth
  hardware.bluetooth.enable = true;

  security.rtkit.enable = true;

  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.rothe = {
    isNormalUser = true;
    description = "rothe";
    extraGroups = [ "networkmanager" "wheel" "video" "scanner" "lp" "incus-admin" "dialout" ];
    shell = pkgs.fish;
    packages = with pkgs; [
      chromium
      firefox
      logseq
      thunderbird
    ];
  };

  nixpkgs.config.permittedInsecurePackages = [
    "electron-27.3.11"
  ];
  nixpkgs.config.allowUnfree = true;

  environment.systemPackages = with pkgs; [
    avrdude
    cryptsetup
    ffmpeg
    fzf
    gammastep
    glib
    gnupg
    ispell
    keychain
    hugo
    mosquitto
    mypy
    sqlite
  ];

  services.pcscd.enable = true;
  services.passSecretService.enable = true;
  services.gvfs.enable = true;


  services.blueman.enable = true;
  services.fwupd.enable = true;

  networking.nftables = {
    enable = true;
  };
  networking.firewall.trustedInterfaces = [ "incusbr0" ];
  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "23.05"; # Did you read the comment?

  virtualisation = {
    incus.enable = false;
    podman.enable = true;
  };
}
